@@ -11,12 +11,12 @@ import numpy as np
 rod0 = np.zeros([2, 3])
 rod0[:, 1] = np.r_[0, np.pi]
 qxz = np.mgrid[-6:6:50j, -6:6:50j].reshape(2, -1).T
-ffe = js.ff.orientedCloudScattering(qxz, rod0, coneangle=10, nCone=10, rms=0)
+ffe = js.ff.orientedCloudScattering(qxz, rod0, mosaicity=[10,0,0], nCone=10, rms=0)
 fig = js.mpl.surface(ffe.X, ffe.Z, ffe.Y)
 fig.axes[0].set_title('cos**2 for Z and slow decay for X')
 fig.show()
 # noise in positions
-ffe = js.ff.orientedCloudScattering(qxz, rod0, coneangle=10, nCone=100, rms=0.1)
+ffe = js.ff.orientedCloudScattering(qxz, rod0, mosaicity=[10,0,0], nCone=100, rms=0.1)
 fig = js.mpl.surface(ffe.X, ffe.Z, ffe.Y)
 fig.axes[0].set_title('cos**2 for Y and slow decay for X with position noise')
 fig.show()
@@ -25,7 +25,7 @@ fig.show()
 # asymmetry is due to small nCone and reflects the used Fibonacci lattice
 rod0 = np.zeros([2, 3])
 rod0[:, 2] = np.r_[0, np.pi]
-ffe = js.ff.orientedCloudScattering(qxz, rod0, coneangle=45, nCone=10, rms=0.05)
+ffe = js.ff.orientedCloudScattering(qxz, rod0, mosaicity=[45,0,0], nCone=10, rms=0.05)
 fig2 = js.mpl.surface(ffe.X, ffe.Z, ffe.Y)
 fig2.axes[0].set_title('symmetric around zero')
 fig2.show()
@@ -34,8 +34,8 @@ fig2.show()
 rod0 = np.zeros([5, 3])
 rod0[:, 1] = np.r_[0, 1, 2, 3, 4] * 3
 qxz = np.mgrid[-6:6:50j, -6:6:50j].reshape(2, -1).T
-ffe = js.ff.orientedCloudScattering(qxz, rod0, formfactor='sphere', V=4 / 3. * np.pi * 2 ** 3, coneangle=20, nCone=30,
-                                    rms=0.02)
+ffe = js.ff.orientedCloudScattering(qxz, rod0, formfactoramp='sphere', V=4 / 3. * np.pi * 2 ** 3, mosaicity=[20,0,0],
+                                    nCone=30, rms=0.02)
 fig4 = js.mpl.surface(ffe.X, ffe.Z, np.log10(ffe.Y), colorMap='gnuplot')
 fig4.axes[0].set_title('5 spheres with R=2 along Z with noise (rms=0.02)')
 fig4.show()
@@ -52,7 +52,7 @@ q = np.unique(sorted(qrpt[:, 0]))
 q = js.loglist(0.01, 7, 100)
 # explicitly given isotropic form factor amplitude
 cs = js.ff.sphereCoreShell(q=q, Rc=1, Rs=2, bc=0.1, bs=1, solventSLD=0)[[0, 2]]
-ffe = js.ff.orientedCloudScattering(qxz, rod0, formfactor=cs, coneangle=20, nCone=100, rms=0.05)
+ffe = js.ff.orientedCloudScattering(qxz, rod0, formfactoramp=cs, mosaicity=[20,0,0], nCone=100, rms=0.05)
 fig4 = js.mpl.surface(ffe.X, ffe.Z, np.log10(ffe.Y), colorMap='gnuplot')
 fig4.axes[0].set_title('5 core shell particles with R=2 along Z with noise (rms=0.05)')
 fig4.show()
@@ -73,7 +73,7 @@ q = np.unique(sorted(qrpt[:, 0]))
 # or use interpolation
 q = js.loglist(0.01, 7, 100)
 cs = js.ff.sphereCoreShell(q=q, Rc=1, Rs=2, bc=0.1, bs=1, solventSLD=0)[[0, 2]]
-ffe = js.ff.orientedCloudScattering(qxz, rod0, formfactor=cs, coneangle=20, nCone=100, rms=0.05)
+ffe = js.ff.orientedCloudScattering(qxz, rod0, formfactoramp=cs, mosaicity=[20,0,0], nCone=100, rms=0.05)
 fig4 = js.mpl.surface(ffe.X, ffe.Z, np.log10(ffe.Y), colorMap='gnuplot')
 fig4.axes[0].set_title('5 core shell particles with R=2 along Z with noise (rms=0.05)')
 fig4.show()
@@ -103,7 +103,7 @@ qxzy = np.c_[x, x * 0, x * 0]
 for alpha in np.r_[0:91:30]:
     R = js.formel.rotationMatrix(np.r_[0, 0, 1], np.deg2rad(alpha))  # rotate around Z axis
     qa = np.dot(R, qxzy.T).T[:, :2]
-    ffe = js.ff.orientedCloudScattering(qa, rod0, formfactor=cs, coneangle=20, nCone=100, rms=0.05)
+    ffe = js.ff.orientedCloudScattering(qa, rod0, formfactoramp=cs, mosaicity=[20,0,0], nCone=100, rms=0.05)
     p.plot(x, ffe.Y, li=[1, 2, -1], sy=0, le='alpha=%g' % alpha)
 p.xaxis(label=r'Q / nm\S-1')
 p.legend()
