@@ -19,76 +19,60 @@
 #
 """
 This is a rudimentary interface to `matplotlib <https://matplotlib.org/>`_ to use dataArrays/sasImage easier.
-The standard way to use matplotlib is full available without using this module.
-Nevertheless the source can be used as template to be adapted.
-
-You may switch to use mpl in fitting and examples using ::
-
- js.usempl(True)
+The standard way to use matplotlib is full available without using this module and recomended for more
+complicated use cases. Nevertheless the source can be used as template to be adapted.
 
 The intention is to allow fast/easy plotting (one command to plot) with some convenience
 function in relation to dataArrays and in a non blocking mode of matplotlib.
-E.g. to include automatically the value of an attribute (qq in example) in the legend::
+E.g. to include automatically the value of an attribute (qq in example) in the legend for daily work
+and inspection of your data ::
 
- fig[0].Plot(mydataArray, legend='sqr=$qq',sy=[2,3,-1],li=0)
- # dataList
- fig[0].Plot(mydataList , legend='sqr=$qq',sy=[2,3,-1],li=0)
+ fig = js.mplot()
+ fig[0].Plot(mydataArray, legend='sqr=$qq',sy=[2,3,-1], li=0)
+ fig[0].Plot(mydataList , legend='sqr=$qq',sy=[2,3,-1], li=0)
 
-With somehow shorter form to determine the marker (sy=symbol) and line (li)
-and allow plotting in one line. Matplotlib is quite slow (and looks for me ugly).
-For 2D plotting use xmgrace.
-For 3D plotting this will give some simple plot options (planned).
+We have some shortcuts to determine the marker (sy=symbol) and line (li) and legend (le).
+Matplotlib is quite slow, for faster 2D plotting use xmgrace (e.g. updates during fits are much faster).
+For 3D plotting we have some simple plot functions to get a result in one line.
 
-* The new methods introduced all start with a big Letter to allow still the access of the original methods.
+* ``js.usempl(True)`` switches to mpl in fitting and examples.
+* The new methods introduced all start with a big Letter to allow still the access of the original matplotlib
+  methods.
 * By indexing subplots can be accessed as figure[i] which is figure.axes[i].
 * Same for axes with lines figure[0][i] is figure.axes[0].lines[i].
+* The ``ax`` option of later commands allows to plot in a multi plot.
 
 Example 1::
 
     import jscatter as js
     import numpy as np
+
+    # get some data
     i5=js.dL(js.examples.datapath+'/iqt_1hho.dat')
-    p=js.mplot()
-    p[0].Plot(i5,sy=[-1,0.4,-1],li=1,legend='Q= $q')
-    p[0].Yaxis(scale='l')
-    p[0].Title('intermediate scattering function')
-    p[0].Legend(x=1.13,y=1) # x,y in relative units of the plot
+    x,z=np.mgrid[-4:8:0.1,-3:5:0.1]
+    xyz=js.dA(np.c_[x.flatten(),z.flatten(),0.3*np.sin(x*z/np.pi).flatten()].T)
+    xyz.setColumnIndex(ix=0,iy=2,iz=1)
+
+    # plot it
+    p=js.mplot(20,10)
+    p.Multi(1,2)
+    p[0].Plot(i5,sy=[-1,0.2,-1,-1],li=1,legend='Q= $q')
+    js.mpl.contourImage(xyz,invert_yaxis=True,ax=p[1])
+
+    # pretty up for paper or presentation
+    p[0].Yaxis(scale='l',max=1.1,min=0.05)
+    p[0].Title('Some unrelated data')
+    p[0].Legend(x=1.43,y=1,charsize=0.8) # x,y in relative units of the plot
     p[0].Yaxis(label='I(Q,t)/I(Q,0)',min=0.01)
     p[0].Xaxis(label='Q / 1/nm',max=120)
+    # p.savefig(js.examples.imagepath+'/lineandcontourImage.jpg')
 
-Example 2  ( same as js.mpl.test() )::
+.. image:: ../../examples/images/lineandcontourImage.jpg
+    :align: center
+    :width: 50 %
+    :alt: lines and contourImage
 
-    import jscatter as js
-    import numpy as np
-    from matplotlib import pyplot
-    # use this
-    #fig=pyplot.figure(FigureClass=js.mpl.Figure)
-    # or
-    fig=js.mplot()
-    fig.Multi(2,1)
-    fig[0].SetView(0.1,0.25,0.8,0.9)
-    fig[1].SetView(0.1,0.09,0.8,0.23)
-    q=js.loglist(0.01,5,100)
-    aa=js.dL()
-    for pp in range(5):
-        aa.append(js.dA(np.c_[q,-pp*np.sin(q),0.2*np.cos(5*q)].T))
-        aa[-1].qq=pp
-    bb=js.dA(np.c_[q,q**2].T)
-    bb.qq=123
-    for pp in range(5):
-        fig[0].Plot(aa[pp].X,-1*aa[pp].Y,legend='some stufff',sy=[1,(pp+1)/10.],li=0)
-
-    fig[0].Plot(aa, legend='qq = $qq', sy=[-1, 0.4, -1, ''], li=0, markeredgewidth=1)
-    for pp in range(5):
-        fig[1].Plot(aa[-1].X/5+pp,pp*aa[-1].Y,legend='q=%.1f' %pp,sy=0,li=-1,markeredgewidth =1)
-    fig[1].Plot(bb,legend='sqr=$qq ',sy=2,li=2)
-    fig[0].Title('test')
-    fig[0].Legend(x=1.3,y=1)
-    fig[1].Legend(x=1.3,y=1)
-    fig[0].Yaxis(label='y-axis')
-    fig[1].Yaxis(label='something else')
-    fig[0].tick_params(labelbottom=False)
-    fig[1].Xaxis(label='x-axis')
+See another Example :py:func:`~.test`
 
 **Some short hints for matplotlib**
 Dont use the pyplot interface as it hides how most things work and e.g. how to access lines later.
@@ -97,12 +81,12 @@ After fitting the errorplot can be accessed as ``data.errplot``.
 ::
 
  fig=js.mplot()                         # access figure properties from fig
- fig.axes[0]                            # access to axes properties
- fig.axes[0].lines[0]                   # access to lines properties in axes 0
+ fig.axes[0]                            # access to axes properties first axes
+ fig.axes[1].lines[3]                   # access properties of 3rd line in axes 1
  fig.axes[0].lines[1].set_color('b')    # change color
  fig.axes[0].legend(...)                # set legend
  data.errplot.axes[0].set_yscale('log') # set log scale in errplot
- # for more read matplotlib documentation
+ # for more read matplotlib documentation for object oriented access
 
 """
 
@@ -283,7 +267,9 @@ def _translate(axlen, kwargs, data=None, yerr=None):
 class jspaperAxes(matplotlib.axes.Axes):
     """
     An Axes that should look like typical paper layout.
-    
+
+    This i used from mplot and should not be called directly.
+
     """
 
     name = 'paper'
@@ -387,7 +373,7 @@ class jspaperAxes(matplotlib.axes.Axes):
                     yerr = data.eY
                 else:
                     yerr = None
-                nkwargs = _translate(nlines + 1, kwargs.copy(), data, yerr)
+                nkwargs = _translate(nlines + 1, copy.deepcopy(kwargs), data, yerr)
                 if fmt and 'fmt' not in nkwargs:
                     # if fmt not empty and not other setting found
                     nkwargs['fmt'] = fmt[0]
@@ -399,7 +385,7 @@ class jspaperAxes(matplotlib.axes.Axes):
                         yerr = da.eY
                     else:
                         yerr = None
-                    nkwargs = _translate(nlines + 1, kwargs.copy(), da, yerr)
+                    nkwargs = _translate(nlines + 1, copy.deepcopy(kwargs), da, yerr)
 
                     if fmt and 'fmt' not in nkwargs:
                         # if fmt not empty and not other setting found
@@ -413,7 +399,7 @@ class jspaperAxes(matplotlib.axes.Axes):
                         yerr = data[2]
                     except:
                         yerr = None
-                nkwargs = _translate(nlines + 1, kwargs.copy(), data, yerr)
+                nkwargs = _translate(nlines + 1, copy.deepcopy(kwargs), data, yerr)
                 if fmt and 'fmt' not in nkwargs:
                     # if fmt not empty and not other setting found
                     nkwargs['fmt'] = fmt[0]
@@ -618,6 +604,8 @@ class jsFigure(matplotlib.figure.Figure):
         """
         Create figure with Axes as jspaperAxes projection.
 
+        This i used from mplot and should not be called directly.
+
         Examples
         --------
         ::
@@ -789,7 +777,7 @@ def close(*args, **kwargs):
 
 def mplot(width=None, height=None, **kwargs):
     """
-    Open matplotlib figure in paper layout with methods to display dataArray/dataList.
+    Open matplotlib figure in paper layout with figure/axes methods to display dataArray/dataList.
 
     Paper layout means white background, black axis.
     Plot separates X,Y, eY of dataList automatically.
@@ -878,7 +866,7 @@ def regrid(x, y, z, shape=None):
     return xx, yy, zz
 
 
-def surface(x, y, z, shape=None, levels=8, colorMap='jet', lineMap=None, alpha=0.7):
+def surface(x, y, z, shape=None, levels=8, colorMap='jet', lineMap=None, alpha=0.7, ax=None):
     """
     Surface plot of x,y,z, data
 
@@ -907,6 +895,8 @@ def surface(x, y, z, shape=None, levels=8, colorMap='jet', lineMap=None, alpha=0
             w: white
     alpha : float [0,1], default 0.7
         Transparency of surface
+    ax : figure axes, default None
+        Axes to plot inside. If None a new Figure is opened.
 
     Returns
     -------
@@ -940,8 +930,12 @@ def surface(x, y, z, shape=None, levels=8, colorMap='jet', lineMap=None, alpha=0
     except ValueError:
         lmap = lineMap
 
-    fig = figure()
-    ax = fig.add_subplot(111, projection='3d')
+    if ax is None:
+        fig = figure()
+        ax = fig.add_subplot(1, 1, 1, projection='3d')
+    else:
+        fig = ax.figure
+
     surf = ax.plot_surface(X, Y, Z, cmap=cmap, linewidth=1, antialiased=True, alpha=alpha)
     # noinspection PyBroadException
     try:
@@ -1013,11 +1007,6 @@ def scatter3d(x, y=None, z=None, pointsize=3, color='k', ax=None):
     ax.set_xlabel('X axis')
     ax.set_ylabel('Y axis')
     ax.set_zlabel('Z axis')
-    try:
-        ax.set_aspect("equal")
-    except NotImplementedError:
-        # It is not currently possible to manually set the aspect on 3D axes
-        pass
     fig.tight_layout()
     # fig.colorbar(scatter ,shrink=0.8) # note that colorbar is a method of the figure, not the axes
     show(block=False)
@@ -1031,7 +1020,7 @@ def _isregularspaced(sequence):
 
 def contourImage(x, y=None, z=None, levels=None, fontsize=10, colorMap='jet', scale='norm', lineMap=None,
                  axis=None, origin=None, block=False, invert_yaxis=False, invert_xaxis=False,
-                 linthresh=1, linscale=1, badcolor=None):
+                 linthresh=1, linscale=1, badcolor=None, ax=None):
     """
     Image with contour lines of 3D dataArrays or sasImage/image array.
 
@@ -1093,6 +1082,8 @@ def contourImage(x, y=None, z=None, levels=None, fontsize=10, colorMap='jet', sc
         See matplotlib imshow.
     block : bool
         Open in blocking or non-blocking mode
+    ax : figure axes, default None
+        Axes to plot inside. If None a new Figure is opened.
 
     Returns
     -------
@@ -1170,11 +1161,41 @@ def contourImage(x, y=None, z=None, levels=None, fontsize=10, colorMap='jet', sc
      xyz.setColumnIndex(ix=0,iy=2,iz=1)
      js.mpl.contourImage(xyz)
 
+    A multiplot figure
+    ::
+
+     import jscatter as js
+     import numpy as np
+     # On a regular grid
+     x,z=np.mgrid[-4:8:0.1,-3:5:0.1]
+     xyz=js.dA(np.c_[x.flatten(),
+                     z.flatten(),
+                     0.3*np.sin(x*z/np.pi).flatten()+0.01*np.random.randn(len(x.flatten())),
+                     0.01*np.ones_like(x).flatten() ].T)
+     # set columns where to find X,Y,Z )
+     xyz.setColumnIndex(ix=0,iy=2,iz=1)
+     # first X value (here -4) is in [0,0] upper left corner, so we invert the corresponding axis
+
+     # plot in multi axes
+     fig = js.mplot(20,10)
+     fig.Multi(1,2)
+     js.mpl.contourImage(xyz,invert_yaxis=True,ax=fig[1])
+     i5=js.dL(js.examples.datapath+'/iqt_1hho.dat')
+     fig[0].Plot(i5,sy=[-1,0.4,-1],li=1,legend='Q= $q')
+     #fig.savefig(js.examples.imagepath+'/multiContourImage.jpg')
+
+    .. image:: ../../examples/images/multiContourImage.jpg
+     :align: center
+     :width: 50 %
+     :alt: multiContourImage
 
 
     """
-    fig = figure()
-    ax = fig.add_subplot(1, 1, 1)
+    if ax is None:
+        fig = figure()
+        ax = fig.add_subplot(1, 1, 1)
+    else:
+        fig = ax.figure
 
     # use copy so that we do not mutate the global colormap instance; stupid matplotlib programmers
     cmap = copy.copy(matplotlib.cm.get_cmap(colorMap))
@@ -1325,6 +1346,9 @@ def contourOnCube(xy, yz=None, xz=None, shape=None, offset=None, levels=None, co
         E.g. 10 uses 1 decade.
     block : bool
         Open in blocking or non-blocking mode
+    ax : figure axes, default None
+        Axes to plot inside. If None a new Figure is opened.
+
 
     Returns
     -------
@@ -1721,7 +1745,7 @@ def showlastErrPlot2D(data, lastfit=None, shape=None, scale='norm', colorMap='je
 
 def plot2Dimage(data, shape=None, yaxis_label='Z', xaxis_label='X', method='nearest', colorMap='jet', scale='norm',
                 linthresh=1, linscale=1, badcolor=None, transpose=None, figsize=[6, 6], origin='upper',
-                txtkwargs={'fontsize': 'small'}):
+                txtkwargs={'fontsize': 'small'}, ax=None):
     """
     Show a 2D image of a dataarray with XZW values like from oriented cloudscattering.
 
@@ -1769,6 +1793,8 @@ def plot2Dimage(data, shape=None, yaxis_label='Z', xaxis_label='X', method='near
     txtkwargs : kwargs
         Keyword arguments passed to Text https://matplotlib.org/api/text_api.html#matplotlib.text.Text).
         except x,y,text arguments.
+    ax : figure axes, default None
+        Axes to plot inside. If None a new Figure is opened.
 
 
     Returns
@@ -1793,7 +1819,7 @@ def plot2Dimage(data, shape=None, yaxis_label='Z', xaxis_label='X', method='near
      # Orient 111 direction perpendicular to qxy plane
      fcclattice.rotatehkl2Vector([1,1,1],[0,0,1])
      # rotation by 15 degrees to be aligned to xy plane
-     fcclattice.rotateAroundhkl([1,1,1],np.deg2rad(15))
+     fcclattice.rotateAroundhkl([1,1,1],np.deg2rad(-15))
      ffs=js.sf.orientedLatticeStructureFactor(qxyz,fcclattice, rotation=[1,1,1,np.deg2rad(10)],
                                 domainsize=ds,rmsd=0.1,hklmax=5,nGauss=23)
 
@@ -1844,8 +1870,11 @@ def plot2Dimage(data, shape=None, yaxis_label='Z', xaxis_label='X', method='near
 
         extend = [extend[2], extend[3], extend[0], extend[1]]
 
-    fig = figure(figsize=figsize)
-    ax1 = fig.add_subplot(1, 1, 1)
+    if ax is None:
+        fig = figure(figsize=figsize)
+        ax1 = fig.add_subplot(1, 1, 1)
+    else:
+        fig = ax.figure
 
     # add images and and some text
     norm1.autoscale(Y)
@@ -1865,6 +1894,8 @@ def test(keepopen=True):
     """
     A small test for mpl module making a plot.
 
+    Run as ``js.mpl.test()``
+
     Examples
     --------
     ::
