@@ -117,7 +117,6 @@ def haltonSequence(size, dim, skip=0):
      ax.set_xlim([-1,1])
      ax.set_ylim([-1,1])
      ax.set_zlim([-1,1])
-     ax.set_aspect("equal")
      plt.tight_layout()
      plt.show(block=False)
 
@@ -292,7 +291,6 @@ def randomPointsInCube(NN, skip=0, dim=3):
      ax.set_xlim([0,3])
      ax.set_ylim([0,3])
      ax.set_zlim([0,3])
-     ax.set_aspect("equal")
      plt.tight_layout()
      plt.show(block=False)
      #fig.savefig(js.examples.imagepath+'/randomRandomCubes.jpg')
@@ -346,14 +344,13 @@ def fibonacciLatticePointsOnSphere(NN, r=1):
      ax.set_xlim([-1,1])
      ax.set_ylim([-1,1])
      ax.set_zlim([-1,1])
-     ax.set_aspect("equal")
      plt.tight_layout()
      plt.show(block=False)
 
      points=js.formel.fibonacciLatticePointsOnSphere(1000)
      pp=list(filter(lambda a:(a[2]>0.3) & (a[2]<1) ,points))
      v=js.formel.rphitheta2xyz(pp)
-     R=js.formel.rotationMatrix([1,0,0],np.deg2rad(-30))
+     R=js.formel.rotationMatrix([1,0,0],np.deg2rad(30))
      pxyz=np.dot(R,v.T).T
      #points in polar coordinates
      prpt=js.formel.xyz2rphitheta(np.dot(R,pxyz.T).T)
@@ -363,7 +360,6 @@ def fibonacciLatticePointsOnSphere(NN, r=1):
      ax.set_xlim([-1,1])
      ax.set_ylim([-1,1])
      ax.set_zlim([-1,1])
-     ax.set_aspect("equal")
      ax.set_xlabel('x')
      ax.set_ylabel('y')
      ax.set_zlabel('z')
