@@ -1062,22 +1062,23 @@ def AgBeReference(q, wavelength, n=np.r_[1:10], ampn=None, domainsize=100, udw=0
     The intensities assume a d-spacing of 5.8378 nm and a reduction of the intensity as q**-2.
     The domain size determines the width according to Scherrer equation [2]_. The first peak is at 1.076 1/nm.
     The result needs to be convoluted with the instrument resolution by resFunct or smear.
+    Here only the main planes of AgBe are takn into account. See example.
 
     Parameters
     ----------
     q : array
-        Wavevector
+        Wavevector in units 1/nm.
     wavelength : float
-        Wavelength
+        Wavelength, units nm.
     n : array of int
-        Order of the peaks.
+        Order of the peaks to calculate.
     ampn : list of float
-        Amplitudes of the peaks
+        Amplitudes of the peaks.
     domainsize : float
         Domainsize of AgBe crystals in nm.
         default 100 nm as is given in [1]_.
     udw : float
-        Displacement u in Debye Waller factor exp(-u**2*q**2/3)
+        Displacement u in Debye Waller factor exp(-u**2*q**2/3) in units nm.
     asym : float
         Factor asymmetry in Voigt function describing the peaks.
     lg : float
@@ -1088,6 +1089,55 @@ def AgBeReference(q, wavelength, n=np.r_[1:10], ampn=None, domainsize=100, udw=0
     -------
     dataArray
 
+    Examples
+    --------
+    Xray AgBe measurement
+
+    The simplified plane model is good enough for peak determination
+    while the crystallographic model gets the high order peaks intensities better.
+    ::
+
+     import numpy as np
+     import jscatter as js
+
+     #
+     # Look at raw calibration measurement
+     calibration = js.sas.sasImage(js.examples.datapath+'/calibration.tiff')
+     bc=calibration.center
+     calibration.mask4Polygon([bc[0]+8,bc[1]],[bc[0]-8,bc[1]],[bc[0]-8+60,0],[bc[0]+8+60,0])
+     # mask center
+     calibration.maskCircle(calibration.center, 18)
+     # mask outside shadow
+     calibration.maskCircle([500,320], 280,invert=True)
+     # calibration.show(axis='pixel',scale='log')
+     cal=calibration.radialAverage()
+
+     # lattice from crystallographic data in cif file.
+     agbe=js.sf.latticeFromCIF(js.examples.datapath + '/1507774.cif',size=[0,0,0])
+     sfagbe=js.sf.latticeStructureFactor(cal.X, lattice=agbe,
+                                        domainsize=50, rmsd=0.001, lg=1, hklmax=17,wavelength=0.15406)
+
+     # simplified model of planes
+     ag = js.sas.AgBeReference(q=sfagbe.X, wavelength=0.13414, n=np.r_[1:14], domainsize=50)
+
+     p=js.grace()
+     p.plot(cal, le='measured AgBe powder')
+     # add scaling and background (because of unscaled raw data)
+     p.plot(sfagbe.X,190*sfagbe.Y+1.9,sy=0,li=[1,3,4],legend='from cif data')
+     p.plot(ag.X, ag.Y*3+1.9, sy=0, li=[1,3,5],le='plane structure')
+     p.yaxis(scale='log',label='I(q) / counts/pixel')
+     p.xaxis(scale='log',label='q / nm|S-1',min=0.7,max=20)
+     p.title('AgBe reference measurements')
+     p.legend(x=4,y=500)
+     # p.save(js.examples.imagepath+'/AgBeplanes.jpg')
+
+    .. image:: ../../examples/images/AgBeplanes.jpg
+     :align: center
+     :width: 50 %
+     :alt: AgBeplanes
+
+
+
     References
     ----------
     .. [1] T. C. Huang, H. Toraya, T. N. Blanton and Y. Wu
@@ -1100,15 +1150,24 @@ def AgBeReference(q, wavelength, n=np.r_[1:10], ampn=None, domainsize=100, udw=0
 
     """
     if ampn is None:
-        ampn = [1] * 10
+        ampn = np.ones_like(n)
+
+    if np.any(q/4/np.pi*wavelength > 1):
+        raise ValueError('Some q values are to large for this wavelength.')
+
     dspacing = 5.8378  # nm
-    braggAngle = 2 * np.arcsin(n * wavelength / 2. / dspacing)  # as 2*Theta
+    theta2 = n * wavelength / 2. / dspacing  # as 2*Theta
+    theta2= theta2[theta2<=1]  # filter too large orders
+    braggAngle = 2 * np.arcsin(theta2)
     theta = lambda q: 2 * np.arcsin(q / 4 / np.pi * wavelength)
+
     # Scherer equation for broadening due to finite size
     beta = 0.9 * wavelength / (domainsize * np.cos(braggAngle))  # beta is FWHM in rad
+
     # the peaks are described as Gaussians in theta
     peaks = np.c_[[voigt(theta(q), center=m, lg=lg, fwhm=fw, asym=asym).Y * a for m, fw, a in
                    zip(braggAngle, beta, ampn)]].sum(axis=0) / q ** 2 * np.exp(-q ** 2 * udw ** 2 / 3.)
+
     result = dA(np.c_[q, peaks].T)
     result.setColumnIndex(iey=None)
     result.columnname = 'wavevector; intensity'
@@ -1612,7 +1671,7 @@ def _find_peak(beam, edge):
     while beam.Y[imax + 1] < beam.Y[imax]:       imax += 1
     while beam.Y[imin - 1] < beam.Y[imin]:       imin -= 1
     temp = beam[:, imin:imax]
-    centerTransmissionPeak = (temp.X * temp.Y / temp.Y.sum()).mean()
+    centerTransmissionPeak = (temp.X * temp.Y).sum() / temp.Y.sum()
     return centerTransmissionPeak, transmission
 
 
