@@ -44,6 +44,8 @@ import scipy
 from scipy import special
 import pickle
 from numpy import linalg as la
+from scipy.spatial.transform import Rotation as Rot
+
 
 # noinspection PyPackageRequirements
 import jscatter as js
@@ -258,7 +260,7 @@ class dataListTest(unittest.TestCase):
 
         # data
         self.diff = js.dL(os.path.join(js.examples.datapath, 'iqt_1hho.dat'))
-        self.i5=self.diff[[1, 5, 10]]
+        self.i5 = self.diff[[1, 5, 10]]
         self.diffm = self.diff.copy()
 
         def model(A, D, t, wave=0):
@@ -294,8 +296,18 @@ class dataListTest(unittest.TestCase):
     def test_basic_merge(self):
         # test mergeAttribut
         diffm = self.diff.copy()
+        diffm[2].miss = 2
+        diffm[5].miss = 5
+        diffm[8].miss = 8
         diffm.mergeAttribut('q')
         self.assertAlmostEqual(diffm.qmean[4], 0.65, places=4)
+        self.assertEqual(diffm.miss[2], 2)
+        self.assertEqual(diffm.miss[1], None)
+        diffm.merge([5, 6], missing='drop')
+        self.assertEqual(diffm.miss[5][0], 8)
+        diffm[5].miss = 88
+        diffm.merge([5, 6], missing='first')
+        self.assertEqual(diffm.miss[5], 88)
 
     def test_basic_append(self):
         # test pop insert append
@@ -326,16 +338,16 @@ class dataListTest(unittest.TestCase):
         self.i5.setLimit(A=[0.8, 1.2])
         self.i5.fit(model=diffusion, freepar={'D': 0.2, 'A': 1},
                                      fixpar={'elastic': 0.0},
-                                     mapNames= {'t': 'X', 'wavevector': 'q'},
+                                     mapNames={'t': 'X', 'wavevector': 'q'},
                                      condition=lambda a: a.X>0.01, output=False)
         self.i5.fit(model=diffusion, freepar={'D': 0.2, 'A': 1},
                                      fixpar={'elastic': 0.0},
-                                     mapNames= {'t': 'X', 'wavevector': 'q'},
+                                     mapNames={'t': 'X', 'wavevector': 'q'},
                                      condition=lambda a: a.X>0.01,
                                      method='BFGS', maxiter=1000, output=False)
         self.i5.fit(model=diffusion, freepar={'D': 0.2, 'A': 1},
                                      fixpar={'elastic': 0.0},
-                                     mapNames= {'t': 'X', 'wavevector': 'q'},
+                                     mapNames={'t': 'X', 'wavevector': 'q'},
                                      condition=lambda a: a.X>0.01,
                                      method='differential_evolution', output=False)
 
@@ -472,7 +484,7 @@ def core_shellsphere(q, Rc, Rs, bc, bs, alpha, solventSLD=0):
 # noinspection PyMethodMayBeStatic
 class formelTest(unittest.TestCase):
     """
-    Test for som things in formel
+    Test for some things in formel
     """
 
     def test_otherStuff(self):
@@ -589,6 +601,11 @@ class formelTest(unittest.TestCase):
         nptest.assert_allclose(result.Y.array.min(axis=1),
                                [1.578e-02, 9.534e-02, 7.509e-01, 2.929e+00, 7.785e+00, 2.704e+01], 1e-4)
 
+    def test_transforms(self):
+        rM = js.formel.rotationMatrix([0, 0, 1], np.deg2rad(90))
+        scipyRm =R=Rot.from_euler('Z',[90],degrees=True).as_matrix()
+        nptest.assert_array_almost_equal(rM, scipyRm[0])
+
 
 class structurefactorTest(unittest.TestCase):
     """
@@ -676,7 +693,7 @@ class sasTest(unittest.TestCase):
 
         # test sasImage calibration
         self.calibration = js.sas.sasImage(os.path.join(js.examples.datapath, 'calibration.tiff'))
-        self.calibration.recalibrateDetDistance()
+        self.calibration.recalibrateDetDistance(peaks=js.sas.AgBepeaks[0:3])
         self.small = self.calibration.reduceSize(2, self.calibration.center, 200)
         small = self.small.copy()
         self.small.data[:, :] = 100
@@ -724,9 +741,9 @@ class sasTest(unittest.TestCase):
     def test_sas(self):
         # peak position of AgBe reference
         AgBeref = js.sas.AgBeReference(self.q, 0.58378)
-        self.assertAlmostEqual(AgBeref.X[AgBeref.Y.argmax()], 1.076, delta=1e-3)
+        self.assertAlmostEqual(AgBeref.X[AgBeref.Y.argmax()], 1.076, delta=2e-3)
 
-        self.assertAlmostEqual(self.calibration.detector_distance[0], 0.18078, delta=1e-4)
+        self.assertAlmostEqual(self.calibration.detector_distance[0], 0.18067, delta=2e-4)
         self.assertAlmostEqual(self.smallamax, 100)
         self.assertAlmostEqual(self.ismallXmax, 1.076, delta=5e-3)
         self.assertAlmostEqual(self.ismallYmax, 824.147, delta=1e-2)
@@ -935,7 +952,7 @@ class plotTest(unittest.TestCase):
             refhexg = '0xadbf67f6c6c0b8e5f91e243bde862fc473c1c871c076d2dec278c643c006d109'
             refgrace = js.formel.imageHash(image=refhexg, type='phash')
             errgracehash = js.formel.imageHash(image='lastErrPlot_kill_grace.png', hashsize=16, type='phash')
-            self.assertLess(refgrace.similarity(errgracehash), 0.07)
+            self.assertLess(refgrace.similarity(errgracehash), 0.09)
 
         refhexm = '0xbeab4d478d0813b7f2f648c899593b39e76c9d8da19787f2b890c858c27ab218'
         refmpl = js.formel.imageHash(image=refhexm, type='phash')
