@@ -32,13 +32,6 @@ import scipy.linalg as la
 from . import formel
 from .dataarray import dataArray as dA
 
-try:
-    import pymatgen
-    cifreaderfound=True
-except ImportError:
-    cifreaderfound=False
-    pass
-
 # variable to allow printout for debugging as if debug:print 'message'
 debug=False
 
